==> syncope-2.1.0-source-release.zip: syncope-2.1.0/client/enduser/src/main/java/org/apache/syncope/client/enduser/adapters/PlatformInfoAdapter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.client.enduser.adapters;

import java.util.Map;
import org.apache.syncope.client.enduser.SyncopeEnduserApplication;
import org.apache.syncope.client.enduser.model.CustomAttributesInfo;
import org.apache.syncope.client.enduser.model.PlatformInfoRequest;
import org.apache.syncope.common.lib.info.PlatformInfo;

public final class PlatformInfoAdapter {

    public static PlatformInfoRequest toPlatformInfoRequest(final PlatformInfo platformInfo,
            final Map<String, CustomAttributesInfo> customForm) {
        PlatformInfoRequest request = new PlatformInfoRequest();
        request.setPwdResetAllowed(platformInfo.isPwdResetAllowed());
        request.setSelfRegAllowed(platformInfo.isSelfRegAllowed());
        request.setPwdResetRequiringSecurityQuestions(platformInfo.isPwdResetRequiringSecurityQuestions());
        request.setVersion(platformInfo.getVersion());
        request.setCaptchaEnabled(SyncopeEnduserApplication.get().isCaptchaEnabled());
        if (SyncopeEnduserApplication.get().getMaxUploadFileSizeMB() != null) {
            request.setMaxUploadFileSizeMB(SyncopeEnduserApplication.get().getMaxUploadFileSizeMB());
        }
        request.setCustomForm(customForm);

        return request;
    }

    private PlatformInfoAdapter() {
        // private constructor for static utility class
    }
}

==> syncope-2.1.13-source-release.zip: syncope-2.1.13/client/enduser/src/main/java/org/apache/syncope/client/enduser/adapters/PlatformInfoAdapter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.client.enduser.adapters;

import java.util.Map;
import org.apache.syncope.client.enduser.SyncopeEnduserApplication;
import org.apache.syncope.client.enduser.model.CustomAttributesInfo;
import org.apache.syncope.client.enduser.model.PlatformInfoRequest;
import org.apache.syncope.common.lib.info.PlatformInfo;

public final class PlatformInfoAdapter {

    public static PlatformInfoRequest toPlatformInfoRequest(final PlatformInfo platformInfo,
            final Map<String, CustomAttributesInfo> customFormAttributes) {
        PlatformInfoRequest request = new PlatformInfoRequest();
        request.setPwdResetAllowed(platformInfo.isPwdResetAllowed());
        request.setSelfRegAllowed(platformInfo.isSelfRegAllowed());
        request.setPwdResetRequiringSecurityQuestions(platformInfo.isPwdResetRequiringSecurityQuestions());
        request.setVersion(platformInfo.getVersion());
        request.setCaptchaEnabled(SyncopeEnduserApplication.get().isCaptchaEnabled());
        if (SyncopeEnduserApplication.get().getMaxUploadFileSizeMB() != null) {
            request.setMaxUploadFileSizeMB(SyncopeEnduserApplication.get().getMaxUploadFileSizeMB());
        }
        request.setCustomFormAttributes(customFormAttributes);

        return request;
    }

    private PlatformInfoAdapter() {
        // private constructor for static utility class
    }
}
